"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.dfToAgrid = exports.booleanFormatter = exports.boolDisplayer = exports.getDatetimeFormatter = exports.dateDisplayerDefault = exports.isValidDate = exports.stringFormatter = exports.basicIntFormatter = exports.updateAtMatch = void 0;
const lodash_1 = __importDefault(require("lodash"));
const updateAtMatch = (cols, key, subst, negative) => {
    const retColumns = cols.map((x) => {
        if (x.field === key) {
            return Object.assign(Object.assign({}, x), subst);
        }
        else {
            return Object.assign(Object.assign({}, x), negative);
        }
    });
    return retColumns;
};
exports.updateAtMatch = updateAtMatch;
/*
  this code should all be unit tested and in examples. Examples will
  show potential developers how this behaves. Examples should be made
  inside of AG-Grid, and independently.
  */
exports.basicIntFormatter = new Intl.NumberFormat('en-US', {
    minimumFractionDigits: 0,
    maximumFractionDigits: 3,
});
const stringFormatter = (params) => {
    const val = params.value;
    return val;
};
exports.stringFormatter = stringFormatter;
const dictDisplayer = (val) => {
    const objBody = lodash_1.default.map(val, (value, key) => `'${key}': ${objDisplayer(value)}`).join(',');
    return `{ ${objBody} }`;
};
const isValidDate = (possibleDate) => {
    if (lodash_1.default.isDate(possibleDate) && isFinite(possibleDate.getTime())) {
        return true;
    }
    return false;
};
exports.isValidDate = isValidDate;
const DEFAULT_DATE_FORMAT = {
    year: 'numeric',
    month: 'numeric',
    day: 'numeric',
    hour: 'numeric',
    minute: 'numeric',
    second: 'numeric',
    hour12: false,
};
const dateDisplayerDefault = (d) => {
    const fullStr = d.toLocaleDateString('en-CA', DEFAULT_DATE_FORMAT);
    const [dateStr, timeStr] = fullStr.split(',');
    //const retVal = `${dateStr} ${timeStr.padStart(12)}`;
    const retVal = `${dateStr} ${timeStr}`;
    return retVal;
};
exports.dateDisplayerDefault = dateDisplayerDefault;
const getDatetimeFormatter = (colHint) => {
    return (params) => {
        // console.log("params", params)
        const val = params.value;
        if (val === null || val === undefined) {
            return '';
        }
        const d = new Date(val);
        if (!(0, exports.isValidDate)(d)) {
            return '';
        }
        if (colHint.formatter === 'default') {
            return (0, exports.dateDisplayerDefault)(d);
        }
        else if (colHint.formatter === 'toLocaleString') {
            return d.toLocaleDateString(colHint.locale, colHint.args);
        }
        throw new Error('unreachable code in getDatetimeFormatter');
    };
};
exports.getDatetimeFormatter = getDatetimeFormatter;
const objDisplayer = (val) => {
    if (val === undefined || val === null) {
        return 'None';
    }
    else if (lodash_1.default.isArray(val)) {
        return `[ ${val.map(objDisplayer).join(', ')}]`;
    }
    else if (lodash_1.default.isBoolean(val)) {
        return (0, exports.boolDisplayer)(val);
    }
    else if (lodash_1.default.isObject(val)) {
        return dictDisplayer(val);
    }
    else {
        return val.toString();
    }
    return val;
};
const objFormatter = (params) => {
    const val = params.value;
    return objDisplayer(val);
};
const boolDisplayer = (val) => {
    if (val === true) {
        return 'True';
    }
    else if (val === false) {
        return 'False';
    }
    return '';
};
exports.boolDisplayer = boolDisplayer;
const booleanFormatter = (params) => {
    const val = params.value;
    return (0, exports.boolDisplayer)(val);
};
exports.booleanFormatter = booleanFormatter;
const getIntegerFormatter = (hint) => {
    const commas = Math.floor(hint.max_digits / 3);
    const totalWidth = commas + hint.max_digits;
    const formatter = new Intl.NumberFormat('en-US');
    const numericFormatter = (params) => {
        const val = params.value;
        if (val === null) {
            return '';
        }
        return formatter.format(params.value).padStart(totalWidth, ' ');
    };
    return numericFormatter;
};
const getFloatFormatter = (hint) => {
    const floatFormatter = new Intl.NumberFormat('en-US', {
        minimumFractionDigits: 3,
        maximumFractionDigits: 3,
    });
    return (params) => {
        if (params.value === null) {
            return '';
        }
        return floatFormatter.format(params.value);
    };
};
function getFormatter(hint) {
    if (hint === undefined) {
        return exports.stringFormatter;
    }
    if (hint.type === 'integer') {
        return getIntegerFormatter(hint);
    }
    else if (hint.type === 'string') {
        return exports.stringFormatter;
    }
    else if (hint.type === 'datetime') {
        return (0, exports.getDatetimeFormatter)(hint);
    }
    else if (hint.type === 'float') {
        return getFloatFormatter(hint);
    }
    else if (hint.type === 'boolean') {
        return exports.booleanFormatter;
    }
    else if (hint.type === 'obj') {
        return objFormatter;
    }
    return exports.stringFormatter;
}
function dfToAgrid(tdf) {
    const fields = tdf.schema.fields;
    //console.log("tdf", tdf);
    //console.log("hints", tdf.table_hints);
    const retColumns = fields.map((f) => {
        //console.log(f.name, tdf.table_hints[f.name])
        const colDef = {
            field: f.name,
            headerName: f.name,
            valueFormatter: getFormatter(lodash_1.default.get(tdf.table_hints, f.name, { is_numeric: false, type: 'obj' })),
        };
        if (f.name === 'index') {
            colDef.pinned = 'left';
        }
        return colDef;
    });
    return [retColumns, tdf.data];
}
exports.dfToAgrid = dfToAgrid;
//# sourceMappingURL=gridUtils.js.map