import { OperationDefaultArgs, Operation } from './OperationUtils';
import { CommandConfigT } from './CommandUtils';
export declare const bakedOperationDefaults: OperationDefaultArgs;
export declare const bakedCommandConfig: CommandConfigT;
export declare const bakedOperations: Operation[];
export interface DFColumn {
    name: string;
    type: string;
}
export type DFDataRow = Record<string, string | number | boolean | any[] | Record<string, any> | null>;
export type DFData = DFDataRow[];
export interface ColumnObjHint {
    type: 'obj';
    histogram?: any[];
}
export interface ColumnDatetimeDefaultHint {
    type: 'datetime';
    formatter: 'default';
    histogram?: any[];
}
export interface ColumnDatetimeFormatHint {
    type: 'datetime';
    formatter: 'toLocaleString';
    locale: 'en-US' | 'en-GB' | 'en-CA' | 'fr-FR' | 'es-ES' | 'de-DE' | 'ja-JP';
    args: Intl.DateTimeFormatOptions;
    histogram?: any[];
}
export type ColumnDatetimeHint = ColumnDatetimeDefaultHint | ColumnDatetimeFormatHint;
export interface ColumnStringHint {
    type: 'string';
    histogram?: any[];
}
export interface ColumnBooleanHint {
    type: 'boolean';
    histogram?: any[];
}
export interface ColumnIntegertHint {
    type: 'integer';
    min_digits: number;
    max_digits: number;
    histogram: any[];
}
export interface ColumnFloatHint {
    type: 'float';
    histogram: any[];
}
export type ColumnHint = ColumnObjHint | ColumnIntegertHint | ColumnDatetimeHint | ColumnFloatHint | ColumnStringHint | ColumnBooleanHint;
export interface DFWhole {
    schema: {
        fields: DFColumn[];
        primaryKey: string[];
        pandas_version: string;
    };
    table_hints: Record<string, ColumnHint>;
    data: DFData;
}
export declare const EmptyDf: DFWhole;
export declare const histograms: {
    num_histo: {
        name: string;
        population: number;
    }[];
    bool_histo: ({
        name: string;
        false: number;
        true?: undefined;
        NA?: undefined;
    } | {
        name: string;
        true: number;
        false?: undefined;
        NA?: undefined;
    } | {
        name: string;
        NA: number;
        false?: undefined;
        true?: undefined;
    })[];
    NA_Only: {
        name: string;
        NA: number;
    }[];
    simple_catgeorical: {
        name: number;
        cat_pop: number;
    }[];
    categorical_histo: ({
        name: string;
        cat_pop: number;
        unique?: undefined;
        NA?: undefined;
    } | {
        name: string;
        unique: number;
        cat_pop?: undefined;
        NA?: undefined;
    } | {
        name: string;
        NA: number;
        cat_pop?: undefined;
        unique?: undefined;
    })[];
    categorical_histo_lt: ({
        name: string;
        cat_pop: number;
        NA?: undefined;
        unique?: undefined;
        longtail?: undefined;
    } | {
        name: string;
        NA: number;
        cat_pop?: undefined;
        unique?: undefined;
        longtail?: undefined;
    } | {
        name: string;
        unique: number;
        longtail: number;
        cat_pop?: undefined;
        NA?: undefined;
    })[];
    all_unique: {
        name: string;
        unique: number;
    }[];
    unique_na: ({
        name: string;
        unique: number;
        NA?: undefined;
    } | {
        name: string;
        NA: number;
        unique?: undefined;
    })[];
    unique_continuous: ({
        name: string;
        population: number;
        unique?: undefined;
    } | {
        name: string;
        unique: number;
        population?: undefined;
    })[];
    unique_continuous_scaled: ({
        name: string;
        population: number;
        unique?: undefined;
    } | {
        name: string;
        unique: number;
        population?: undefined;
    })[];
    unique_continuous_scaled_50: ({
        name: string;
        population: number;
        unique?: undefined;
    } | {
        name: string;
        unique: number;
        population?: undefined;
    })[];
    start_station_categorical: {
        name: string;
        cat_pop: number;
    }[];
};
export declare const foo: DFWhole;
export declare const tableDf: DFWhole;
export declare const stringIndexDf: DFWhole;
